@@ -8,9 +8,8 @@ import zipfile
 from . import constants
 from .attachment_base import AttachmentBase
 from .enums import AttachmentType
-from .prop import FixedLengthProp, VariableLengthProp
-from .properties import Properties
-from .utils import createZipOpen, inputToString, openMsg, prepareFilename, verifyPropertyId, verifyType
+from .utils import createZipOpen, inputToString, openMsg, prepareFilename
+
 
 logger = logging.getLogger(__name__)
 logger.addHandler(logging.NullHandler())
@@ -44,7 +43,7 @@ class Attachment(AttachmentBase):
             else:
                 self.__prefix = msg.prefixList + [dir_, '__substg1.0_3701000D']
                 self.__type = AttachmentType.MSG
-                self.__data = openMsg(self.msg.path, prefix = self.__prefix, parent = self.msg, **self.msg.kwargs)
+                self.__data = openMsg(self.msg.path, prefix = self.__prefix, parentMsg = self.msg, **self.msg.kwargs)
         elif (self.props['37050003'].value & 0x7) == 0x7:
             # TODO Handling for special attacment type 0x7
             self.__type = AttachmentType.WEB
